#ifdef FOR_NSL
#include "lt-defs.h"
#endif

#include "charset.h"

const char8 *CharacterEncodingName[CE_enum_count] = {
    "unknown",
    "UTF-8",
    "ISO-8859-1",
    "UTF-16",
    "UTF-16",
    "ISO-10646-UCS-2",
    "ISO-10646-UCS-2",
};

const char8 *CharacterEncodingNameAndByteOrder[CE_enum_count] = {
    "unknown",
    "UTF-8",
    "ISO-8859-1",
    "UTF-16-B",
    "UTF-16-L",
    "ISO-10646-UCS-2-B",
    "ISO-10646-UCS-2-L",
};

struct character_encoding_alias CharacterEncodingAlias[] = {
    {"ISO-Latin-1", CE_ISO_8859_1},
    {"UCS-2", CE_ISO_10646_UCS_2B},
};
const int CE_alias_count =
    sizeof(CharacterEncodingAlias)/sizeof(CharacterEncodingAlias[0]);

CharacterEncoding InternalCharacterEncoding;

void init_charset(void)
{
    union {char b[2]; short s;} bytes;

    bytes.s = 1;

#if CHAR_SIZE == 8
    InternalCharacterEncoding = CE_ISO_8859_1;
#else
    InternalCharacterEncoding = (bytes.b[0] == 0) ? CE_UTF_16B : CE_UTF_16L;
#endif
}

/* 
 * Return true if enc1 and enc2 are the same for Unicode <= 127.
 * If so, *enc3 is set to enc2 modified to have the same byte order as enc1.
 */

int EncodingsCompatible(CharacterEncoding enc1, CharacterEncoding enc2,
			CharacterEncoding *enc3)
{
    if(enc1 == CE_UTF_8 || enc1 == CE_ISO_8859_1)
    {
	if(enc2 == CE_UTF_8 || enc2 == CE_ISO_8859_1)
	    *enc3 = enc2;
	else
	    return 0;
	return 1;
    }

    if(enc1 == CE_UTF_16B || enc1 == CE_ISO_10646_UCS_2B)
    {
	if(enc2 == CE_UTF_16B || enc2 == CE_UTF_16L)
	    *enc3 = CE_UTF_16B;
	else if(enc2 == CE_ISO_10646_UCS_2B || enc2 == CE_ISO_10646_UCS_2L)
	    *enc3 = CE_ISO_10646_UCS_2B;
	else
	    return 0;
	return 1;
    }

    if(enc1 == CE_UTF_16L || enc1 == CE_ISO_10646_UCS_2L)
    {
	if(enc2 == CE_UTF_16B || enc2 == CE_UTF_16L)
	    *enc3 = CE_UTF_16L;
	else if(enc2 == CE_ISO_10646_UCS_2B || enc2 == CE_ISO_10646_UCS_2L)
	    *enc3 = CE_ISO_10646_UCS_2L;
	else
	    return 0;
	return 1;
    }

    return 0;
}

